'use strict';

var _electron = require('electron');

var _path = require('path');

var _Rx = require('rxjs/Rx');

var _Rx2 = _interopRequireDefault(_Rx);

var _launch = require('./launch');

var _menu = require('./menu');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const log = require('electron-log');

const kernelspecs = require('kernelspecs');

const version = require('../../package.json').version;

const argv = require('yargs').version(version).parse(process.argv.slice(2));

const notebooks = argv._;

_electron.app.on('window-all-closed', () => {
  // On OS X, we want to keep the app and menu bar active
  if (process.platform !== 'darwin') {
    _electron.app.quit();
  }
});

_electron.ipcMain.on('new-kernel', (event, newKernel) => {
  (0, _launch.launchNewNotebook)(newKernel);
});

_electron.ipcMain.on('open-notebook', (event, filename) => {
  (0, _launch.launch)((0, _path.resolve)(filename));
});

const appReady$ = _Rx2.default.Observable.fromEvent(_electron.app, 'ready');

const openFile$ = _Rx2.default.Observable.fromEvent(_electron.app, 'open-file', (event, path) => ({ event, path }));

function openFileFromEvent({ event, path }) {
  event.preventDefault();
  (0, _launch.launch)((0, _path.resolve)(path));
}

const kernelSpecsPromise = kernelspecs.findAll();

// Since we can't launch until app is ready
// and OS X will send the open-file events early,
// buffer those that come early.
openFile$.buffer(appReady$) // Form an array of open-file events from before app-ready
.first() // Should only be the first
.subscribe(buffer => {
  // Now we can choose whether to open the default notebook
  // based on if arguments went through argv or through open-file events
  if (notebooks.length <= 0 && buffer.length <= 0) {
    log.info('launching an empty notebook by default');
    kernelSpecsPromise.then(specs => (0, _launch.launchNewNotebook)(Object.keys(specs)[0]));
  } else {
    notebooks.filter(Boolean).filter(x => x !== '.') // Ignore the `electron .`
    // TODO: Consider opening something for directories
    .forEach(f => (0, _launch.launch)((0, _path.resolve)(f)));
  }
  buffer.forEach(openFileFromEvent);
});

// All open file events after app is ready
openFile$.skipUntil(appReady$).subscribe(openFileFromEvent);

appReady$.subscribe(() => {
  kernelSpecsPromise.then(kernelSpecs => {
    if (Object.keys(kernelSpecs).length !== 0) {
      // Get the default menu first
      _electron.Menu.setApplicationMenu(_menu.defaultMenu);
      // Let the kernels/languages come in after
      (0, _menu.loadFullMenu)().then(menu => _electron.Menu.setApplicationMenu(menu));
    } else {
      _electron.dialog.showMessageBox({
        type: 'warning',
        title: 'No Kernels Installed',
        buttons: [],
        message: 'No kernels are installed on your system.',
        detail: 'No kernels are installed on your system so you will not be ' + 'able to execute code cells in any language. You can read about ' + 'installing kernels at ' + 'https://ipython.readthedocs.io/en/latest/install/kernel_install.html'
      }, index => {
        if (index === 0) {
          _electron.app.quit();
        }
      });
    }
  });
});